@@ -1,6 +1,6 @@
 
 /**
- * PyOtherSide: Asynchronous Python 3 Bindings for Qt 5
+ * PyOtherSide: Asynchronous Python 3 Bindings for Qt 5 and Qt 6
  * Copyright (c) 2014, Thomas Perl <m@thp.io>
  *
  * Permission to use, copy, modify, and/or distribute this software for any
@@ -66,7 +66,6 @@ bool extractPythonLibrary()
     }
 
     QString fname = QString::fromUtf8(info.dli_fname);
-    qDebug() << "Got library name: " << fname;
     // On Android, dladdr() returns only the basename of the file, so we go
     // hunt for the full path in /proc/self/maps, where the shared library is
     // mapped (TODO: We could parse the address range and compare that, too)
@@ -77,7 +76,13 @@ bool extractPythonLibrary()
             QTextStream maps(&mapsf);
             QString line;
             while (!(line = maps.readLine()).isNull()) {
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
+                // Qt::SkipEmptyParts was introduced in Qt 5.14 according to:
+                // https://doc.qt.io/qt-5/qt.html#SplitBehaviorFlags-enum
                 QString filename = line.split(' ', QString::SkipEmptyParts).last();
+#else
+                QString filename = line.split(' ', Qt::SkipEmptyParts).last();
+#endif
                 if (filename.endsWith("/" + fname)) {
                     fname = filename;
                     qDebug() << "Resolved full path:" << fname;
